# frozen_string_literal: true

# Redmine - project management software
# Copyright (C) 2006-2022  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

module Redmine
  module AccessKeys
    unless const_defined?(:ACCESSKEYS)
      ACCESSKEYS = {
        :edit => 'e',
        :quick_search => 'f',
        :search => '4',
        :new_issue => '7',
        :previous => 'p',
        :next => 'n'
      }.freeze
    end

    def self.key_for(action)
      ACCESSKEYS[action]
    end
  end
end
